Package: shinyNextUI
Title: 'HeroUI' 'React' Template for 'shiny' Apps
Version: 0.1.0
Authors@R: 
    c(
        person("David", "Granjon", ,"dgranjon@ymail.com", role = c("aut", "cre")),
        person(family = "Next UI Inc", role = c("ctb", "cph"), comment = "HeroUI template: <https://www.heroui.com/>")
    )
Description: A set of user interface components to create outstanding 'shiny' apps <https://shiny.posit.co/>,  with
    the power of 'React' 'JavaScript' <https://react.dev/>. Seamlessly support dark and light themes, customize CSS with
    'tailwind' <https://tailwindcss.com/>.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
URL: https://rinterface.github.io/shinyNextUI/
Imports: htmltools, shiny, shiny.react, jsonlite
Suggests: testthat (>= 3.0.0), shinytest2, purrr, thematic,
        shiny.router, roxy.shinylive
Config/testthat/edition: 3
Depends: R (>= 2.10)
LazyData: true
NeedsCompilation: no
Packaged: 2025-03-14 06:43:57 UTC; davidgranjon
Author: David Granjon [aut, cre],
  Next UI Inc [ctb, cph] (HeroUI template: <https://www.heroui.com/>)
Maintainer: David Granjon <dgranjon@ymail.com>
Repository: CRAN
Date/Publication: 2025-03-17 08:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 15:09:26 UTC; unix
